@@ -1,3 +1,7 @@
+class MultipleInputData(Exception):
+   """Raised when data used to populate is not valid"""
+   pass
+
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import os
